@@ -169,6 +169,13 @@ from meshed.itools import (
 )
 
 
+def order_subset_from_list(items, sublist):
+    assert set(sublist).issubset(set(items)), f'{sublist} is not contained in {items}'
+    d = {k: v for v, k in enumerate(items)}
+
+    return sorted(sublist, key=lambda x: d[x])
+
+
 def find_first_free_name(prefix, exclude_names=(), start_at=2):
     if prefix not in exclude_names:
         return prefix
@@ -713,8 +720,11 @@ class DAG:
         subgraph_nodes = _descendants.intersection(_ancestors)
         # TODO: When clone ready, use to do `constructor = type(self)` instead of DAG
         # constructor = type(self)  # instead of DAG
+        initial_nodes = self.func_nodes
+        ordered_subgraph_nodes = order_subset_from_list(initial_nodes, subgraph_nodes)
+
         return DAG(
-            func_nodes=subgraph_nodes,
+            func_nodes=ordered_subgraph_nodes,
             cache_last_scope=self.cache_last_scope,
             parameter_merge=self.parameter_merge,
         )
